@@ -40,7 +40,7 @@ class SubmonitorBase(object):
         self._options = options
         self._last_result = None
         self._initialization_status = None
-        self._baselog = logging.getLogger("%s.SubmonitorBase" % __name__)
+        self._baselog = logging.getLogger("{}.SubmonitorBase".format(__name__))
 
     def setup(self, options):
         """
@@ -113,7 +113,7 @@ class SubmonitorBase(object):
             next_execution = monotonic.time() + self._interval
             try:
                 self.action(self._options)
-            except Exception as e:
+            except Exception:
                 # Don't let the submonitor thread die, just retry later
                 self._baselog.error("Error executing submonitor %s, args %r",
                                     self._name, self._options, exc_info=True)
